dirtem
======

`dirtem` is a library and command-line tool to copy a directory by adding variable information.
`jinja` is used as a temlate engine.


Links
-----

* [Documentation](https://phoenixr-codes.github.io/dirtem)
* [Repository](https://github.com/phoenixr-codes/dirtem)
* [PyPI](https://pypi.org/project/dirtem)


ToDo
----

* [ ] add support for every config option
* [ ] add CLI
* [ ] selecting by path, NOT BY directory/file name
